@@ -22,12 +22,12 @@ class ThreadCoroutineExecutor(threading.Thread):
     .. versionadded:: 2.0
 
     Parameters
-    -----------
+    ----------
     wait: :class:`bool`
         Whether to wait for all tasks to finish before exiting context manager. Defaults to ``False``.
 
     Example
-    --------
+    -------
     .. code:: py
 
         import asyncify
@@ -43,7 +43,7 @@ class ThreadCoroutineExecutor(threading.Thread):
     """
 
     def __init__(self, wait: bool = False):
-        super().__init__()
+        super().__init__(daemon=True)
         self.wait = wait
         self._running: bool = False
         self._unfinished_futures: List[asyncio.Future[Any]] = []
